# flake8: noqa: B950
import logging

from odoo.upgrade import util


NS = "odoo.addons.base.maintenance.migrations.base."
_logger = logging.getLogger(NS + __name__)


def migrate(cr, version):
    if util.dbuuid(cr) != "8851207e-1ff9-11e0-a147-001cc0f2115e":
        return

    idx_to_create = [
        "ir_attachment(res_model,res_field,id)",
        "documents_document(attachment_id)",
        "l10n_mx_edi_document(attachment_id)",
        "account_move(l10n_mx_edi_cfdi_attachment_id)",
        "hr_leave(message_main_attachment_id)",
        "sale_subscription(message_main_attachment_id)",
        "hr_payslip(message_main_attachment_id)",
        "ir_attachment(original_id)",
        "account_edi_document(attachment_id)",
        "account_payment(message_main_attachment_id)",
        "hr_applicant(message_main_attachment_id)",
        "account_move(l10n_id_attachment_id)",
        "project_task(displayed_image_id)",
        "account_move(message_main_attachment_id)",
        "hr_expense(message_main_attachment_id)",
        "ir_model_inherit(model_id)",
        "mail_tracking_value(field_id)",
        "ir_property(fields_id)",
        "ir_model_inherit(parent_field_id)",
        "ir_model_fields(relation_field_id)",
        "hr_contract_salary_benefit(res_field_id)",
        "hr_contract_salary_benefit(manual_res_field_id)",
        "hr_contract_salary_personal_info(res_field_id)",
        "marketing_campaign(unique_field_id)",
        "hr_contract_salary_benefit(fold_res_field_id)",
        "hr_contract_salary_benefit(cost_res_field_id)",
        "ir_act_server(link_field_id)",
        "gamification_goal_definition(batch_distinctive_field)",
        "gamification_goal_definition(field_date_id)",
        "ir_act_server(update_field_id)",
        "base_automation(trg_date_resource_field_id)",
        "gamification_goal_definition(field_id)",
        "base_automation(trg_date_id)",
        "ir_model_fields(related_field_id)",
        "ir_model(website_form_default_field_id)",
        "mail_alias(alias_model_id)",
        "payment_transaction(callback_model_id)",
        "mail_alias(alias_parent_model_id)",
        "mail_activity(res_model_id)",
        "rating_rating(parent_res_model_id)",
        "marketing_participant(model_id)",
        "rating_rating(res_model_id)",
        "res_users(partner_id)",
        "mailing_mailing(mailing_model_id)",
        "base_automation(model_id)",
        "ir_model_inherit(parent_id)",
        "account_report(custom_handler_model_id)",
        "documents_workflow_rule(link_model)",
        "documents_link_to_record_wizard(model_id)",
        "mailing_filter(mailing_model_id)",
        "ir_act_server(binding_model_id)",
        "mail_template(model_id)",
        "ir_act_client(binding_model_id)",
        "ir_act_report_xml(binding_model_id)",
        "mail_activity_schedule(res_model_id)",
        "gamification_goal_definition(model_id)",
        "sms_template(model_id)",
        "base_language_export(model_id)",
        "whatsapp_template(model_id)",
        "ir_act_server(update_related_model_id)",
        "ir_act_server(crud_model_id)",
        "crm_case_log(model_id)",
        "ir_act_url(binding_model_id)",
        "privacy_lookup_wizard_line(res_model_id)",
        "ir_act_window(binding_model_id)",
        "calendar_event(res_model_id)",
        "process_node(model_id)",
        "res_partner(parent_id)",
        "mail_template(ref_ir_act_window)",
        "hr_leave_allocation(employee_id)",
        "purchase_order_line(order_id)",
        "hr_leave_allocation(holiday_status_id)",
        "mail_mail(mail_message_id)",
        "slide_slide_partner(slide_id)",
        "hr_expense(product_id)",
        "calendar_attendee(partner_id)",
        "res_partner(commercial_partner_id)",
        "account_move(partner_id)",
        "resource_calendar_leaves(resource_id)",
        "hr_leave(holiday_status_id)",
        "resource_calendar_leaves(calendar_id)",
        "sale_order_line(product_id)",
        "whatsapp_message(mail_message_id)",
        "mail_tracking_value(mail_message_id)",
        "sms_sms(mail_message_id)",
        "mail_message(parent_id)",
        "product_template(uom_id)",
        "discuss_channel(whatsapp_mail_message_id)",
        "mail_message_reaction(message_id)",
        "mail_group_message(mail_message_id)",
        "rating_rating(message_id)",
        "mail_activity_plan(res_model_id)",
        "purchase_order_line(product_id)",
        "gamification_goal(line_id)",
        "account_move_line(product_id)",
        "account_move_line(purchase_line_id)",
        "account_move_line(product_uom_id)",
        "discuss_channel(group_public_id)",
        "res_partner(grade_id)",
        "project_task_user_rel(stage_id)",
        "project_task(stage_id)",
        "project_task_type(mail_template_id)",
        "project_task_type(rating_template_id)",
        "product_template(email_template_id)",
        "mail_notification(mail_mail_id)",
        "mailing_trace(mail_mail_id)",
        "crm_lead(partner_id)",
        "sign_request_item(partner_id)",
        "openerp_enterprise_database_user(user_id)",
        "sale_order(warehouse_id)",
        "mail_activity(activity_type_id)",
        "mail_activity(previous_activity_type_id)",
        "account_move(commercial_partner_id)",
        "mail_activity(recommended_activity_type_id)",
        "sale_order_line(route_id)",
        "survey_user_input(appraisal_id)",
        "res_users(pos_config)",
        "purchase_order(picking_type_id)",
        "mail_message(mail_activity_type_id)",
        "hr_work_entry(contract_id)",
    ]
    fk_names = []
    create_index_queries = []
    for i in range(0, len(idx_to_create)):
        idx_def = idx_to_create[i]
        fk_names.append(f"upgrade_fk_ir_model_idx_{i}")
        create_index_queries.append(f"CREATE INDEX upgrade_fk_ir_model_idx_{i} ON {idx_def}")
    util.ENVIRON["__created_fk_idx"] = list(fk_names)
    _logger.info("creating %s indexes (might be slow)", len(create_index_queries))
    util.parallel_execute(cr, create_index_queries)
